@@ -1,13 +1,16 @@
 #' Run OptiPNG on all PNG files under a directory
 #'
-#' Calls the command \command{optipng} to optimize all PNG files under a
-#' directory.
+#' Call the command \command{optipng} via \code{system2()} to optimize all PNG
+#' files under a directory.
 #' @param dir Path to a directory.
+#' @param files Alternatively, you can choose the specific files to optimize.
+#' @param ... Arguments to be passed to \code{system2()}.
 #' @references OptiPNG: \url{http://optipng.sourceforge.net}.
 #' @export
-optipng = function(dir = '.') {
-  files = list.files(dir, '[.]png$', recursive = TRUE, full.names = TRUE)
-  for (f in files) system2('optipng', shQuote(f))
+optipng = function(
+  dir = '.', files = list.files(dir, '[.]png$', recursive = TRUE, full.names = TRUE), ...
+) {
+  if (Sys.which('optipng') != '') for (f in files) system2('optipng', shQuote(f), ...)
 }
 
 #' Run the commands \command{Rscript} and \command{R CMD}
@@ -269,13 +272,16 @@ upload_ftp = function(file, server, dir = '') {
   }
 }
 
+#' @param solaris Whether to also upload the package to the Rhub server to check
+#'   it on Solaris.
 #' @rdname upload_ftp
 #' @export
 upload_win_builder = function(
   file = pkg_build(), version = c("R-devel", "R-release", "R-oldrelease"),
-  server = c('ftp', 'https')
+  server = c('ftp', 'https'), solaris = pkg_available('rhub')
 ) {
   if (missing(file)) on.exit(file.remove(file), add = TRUE)
+  if (system2('git', 'status', stderr = FALSE) == 0) system2('git', 'pull')
   server = server[1]
   server = switch(
     server,
@@ -312,5 +318,11 @@ upload_win_builder = function(
       }
     })
   }
+
+  if (solaris) rhub::check_on_solaris(
+    file, check_args = '--no-manual', show_status = FALSE,
+    env_vars = c(`_R_CHECK_FORCE_SUGGESTS_` = 'false')
+  )
+
   setNames(unlist(res), version)
 }
